@@ -73,7 +73,7 @@ def check_object_in_footprint(id, wcs_fits, cat, rd=None):
     return has_point
 
 
-def extract_beams_from_flt(root, bucket, id, clean=True, silent=False):
+def extract_beams_from_flt(root, bucket, id, size=32, clean=True, silent=False):
     """
     Download GrismFLT files and extract the beams file
     """
@@ -186,7 +186,7 @@ def extract_beams_from_flt(root, bucket, id, clean=True, silent=False):
                                       run_fit=False, poly_order=7,
                                       master_files=[os.path.basename(file)],
                                       grp=None, bad_pa_threshold=None,
-                                      fit_trace_shift=False, size=32,
+                                      fit_trace_shift=False, size=size,
                                       diff=True, min_sens=0.02,
                                       skip_complete=True, fit_args={},
                                       args_file=args_file,
@@ -310,11 +310,14 @@ def run_grizli_fit(event):
                 event_kwargs[k] = json.loads(event[k])
             except:
                 event_kwargs[k] = event[k]
-
+    
     # Defaults
     if 'skip_started' not in event_kwargs:
         event_kwargs['skip_started'] = True
-
+    
+    if 'size' not in event_kwargs:
+        event_kwargs['size'] = 32
+        
     for k in ['quasar_fit', 'extract_from_flt', 'fit_stars', 'beam_info_only']:
         if k not in event_kwargs:
             event_kwargs[k] = False
@@ -450,6 +453,7 @@ def run_grizli_fit(event):
             pass
 
         status = extract_beams_from_flt(root, event_kwargs['bucket'], id,
+                                        size=event_kwargs['size'],
                                         clean=run_clean, silent=silent)
 
         # Garbage collector
@@ -750,7 +754,7 @@ def run_grizli_fit(event):
                                        args_file=args_file,
                                        **event_kwargs)
         
-        if root == 'fresco-gds-med':
+        if root in ('fresco-gds-med', 'fresco-gdn-med'):
             try:
                 mb, tfit = res[0], res[3]
                 # 1D for FRESCO
@@ -810,13 +814,17 @@ def run_grizli_fit(event):
             grizli_db.add_redshift_fit_row(rowfile, table=dbtable,
                                            verbose=True)
 
+    except:
+        print('Update row failed')
+        pass
+    
+    try:
         # Add 1D spectra
         files = glob.glob('{0}_{1:05d}*1D.fits'.format(root, id))
         if (len(files) > 0) & (dbtable == 'redshift_fit_v2'):
             grizli_db.send_1D_to_database(files=files)
-
     except:
-        print('Update row failed')
+        print(f'send_1D_to_database {files} failed')
         pass
 
     # Remove start log now that done
